[![Build Status](https://github.com/dbbs-lab/bsb-hdf5/actions/workflows/main.yml/badge.svg)](https://github.com/dbbs-lab/bsb-hdf5/actions/workflows/main.yml)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)

# bsb-hdf5

`bsb-hdf5` is a plugin of the [BSB](https://github.com/dbbs-lab/bsb) (see also 
[bsb-core](https://github.com/dbbs-lab/bsb-core)). 
It contains the storage engine allowing the user to save and load their models' 
in HDF5 files.
